pub struct HttpServer { /* private fields */ }Expand description
A HTTP server for general use.
The HTTP server provides configuration for receiving and responding to HTTP incoming requests.
host: the network address to bind with.port: the port to bind with.
HttpServer aims to be used with connection treatment.
Every time a new HTTP request matching a configured route comes, a new track is created with @HttpRequest context.
ℹ️ If server binding fails, failedBinding is emitted.
⚠️ Use HttpServer with connection treatment, as using incoming source and outgoing treatment directly should be done carefully.
Implementations
Sourceimpl HttpServer
impl HttpServer
pub fn new(model: Weak<HttpServerModel>) -> Self
pub fn statuses( &self, ) -> AsyncArc<AsyncRwLock<HashMap<Uuid, AsyncProducer<Status, Arc<AsyncRb<Status, SharedRb<Status, Vec<MaybeUninit<Status>>>>>>>>> ⓘ
pub fn headers( &self, ) -> AsyncArc<AsyncRwLock<HashMap<Uuid, AsyncProducer<StringMap, Arc<AsyncRb<StringMap, SharedRb<StringMap, Vec<MaybeUninit<StringMap>>>>>>>>> ⓘ
pub fn outgoing( &self, ) -> AsyncArc<AsyncRwLock<HashMap<Uuid, AsyncProducer<u8, Arc<AsyncRb<u8, SharedRb<u8, Vec<MaybeUninit<u8>>>>>>>>> ⓘ